@@ -4,10 +4,10 @@ use strict;
 use warnings;
 use 5.008001;
 use Test2::API qw( context );
-our @ISA = qw( Log::Log4perl::Appender );
+use parent qw( Log::Log4perl::Appender );
 
 # ABSTRACT: Append to TAP output
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 
 sub new
@@ -45,7 +45,7 @@ Log::Log4perl::Appender::TAP - Append to TAP output
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -65,19 +65,33 @@ version 0.04
 
 =head1 DESCRIPTION
 
-This very simple appender sends log output via L<Test2::API> to TAP
+This very simple L<Log::Log4perl> appender sends log output via L<Test2::API> to TAP
 (or any other format supported by L<Test2::API>).  It also works with
 L<Test::Builder> and L<Test::More> so long as you have L<Test2::API>
 installed.  It only takes one special argument, the method, which can
 be either C<diag> or C<note>.
 
+=head1 SEE ALSO
+
+=over 4
+
+=item L<Log::Log4perl>
+
+Main module documentation for C<Log4perl>.
+
+=item L<Log::Dispatch::TAP>
+
+Similar module but for L<Log::Dispatch> instead of C<Log4perl>.
+
+=back
+
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Graham Ollis.
+This software is copyright (c) 2017-2022 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
